@@ -25,6 +25,7 @@ SENSE_CODE(0x0, 0x1d, "ATA PASS THROUGH INFORMATION AVAILABLE") \
 SENSE_CODE(0x0, 0x1e, "CONFLICTING SA CREATION REQUEST") \
 SENSE_CODE(0x0, 0x1f, "LOGICAL UNIT TRANSITIONING TO ANOTHER POWER CONDITION") \
 SENSE_CODE(0x0, 0x20, "EXTENDED COPY INFORMATION AVAILABLE") \
+SENSE_CODE(0x0, 0x21, "ATOMIC COMMAND ABORTED DUE TO ACA") \
 SENSE_CODE(0x1, 0x0, "NO INDEX/SECTOR SIGNAL") \
 SENSE_CODE(0x2, 0x0, "NO SEEK COMPLETE") \
 SENSE_CODE(0x3, 0x0, "PERIPHERAL DEVICE WRITE FAULT") \
@@ -44,6 +45,7 @@ SENSE_CODE(0x4, 0xa, "LOGICAL UNIT NOT ACCESSIBLE, ASYMMETRIC ACCESS STATE TRANS
 SENSE_CODE(0x4, 0xb, "LOGICAL UNIT NOT ACCESSIBLE, TARGET PORT IN STANDBY STATE") \
 SENSE_CODE(0x4, 0xc, "LOGICAL UNIT NOT ACCESSIBLE, TARGET PORT IN UNAVAILABLE STATE") \
 SENSE_CODE(0x4, 0xd, "LOGICAL UNIT NOT READY, STRUCTURE CHECK REQUIRED") \
+SENSE_CODE(0x4, 0xe, "LOGICAL UNIT NOT READY, SECURITY SESSION IN PROGRESS") \
 SENSE_CODE(0x4, 0x10, "LOGICAL UNIT NOT READY, AUXILIARY MEMORY NOT ACCESSIBLE") \
 SENSE_CODE(0x4, 0x11, "LOGICAL UNIT NOT READY, NOTIFY (ENABLE SPINUP) REQUIRED") \
 SENSE_CODE(0x4, 0x12, "LOGICAL UNIT NOT READY, OFFLINE") \
@@ -59,6 +61,10 @@ SENSE_CODE(0x4, 0x1b, "LOGICAL UNIT NOT READY, SANITIZE IN PROGRESS") \
 SENSE_CODE(0x4, 0x1c, "LOGICAL UNIT NOT READY, ADDITIONAL POWER USE NOT YET GRANTED") \
 SENSE_CODE(0x4, 0x1d, "LOGICAL UNIT NOT READY, CONFIGURATION IN PROGRESS") \
 SENSE_CODE(0x4, 0x1e, "LOGICAL UNIT NOT READY, MICROCODE ACTIVATION REQUIRED") \
+SENSE_CODE(0x4, 0x1f, "LOGICAL UNIT NOT READY, MICROCODE DOWNLOAD REQUIRED") \
+SENSE_CODE(0x4, 0x20, "LOGICAL UNIT NOT READY, LOGICAL UNIT RESET REQUIRED") \
+SENSE_CODE(0x4, 0x21, "LOGICAL UNIT NOT READY, HARD RESET REQUIRED") \
+SENSE_CODE(0x4, 0x22, "LOGICAL UNIT NOT READY, POWER CYCLE REQUIRED") \
 SENSE_CODE(0x5, 0x0, "LOGICAL UNIT DOES NOT RESPOND TO SELECTION") \
 SENSE_CODE(0x6, 0x0, "NO REFERENCE POSITION FOUND") \
 SENSE_CODE(0x7, 0x0, "MULTIPLE PERIPHERAL DEVICES SELECTED") \
@@ -72,6 +78,7 @@ SENSE_CODE(0x9, 0x1, "TRACKING SERVO FAILURE") \
 SENSE_CODE(0x9, 0x2, "FOCUS SERVO FAILURE") \
 SENSE_CODE(0x9, 0x3, "SPINDLE SERVO FAILURE") \
 SENSE_CODE(0x9, 0x4, "HEAD SELECT FAULT") \
+SENSE_CODE(0x9, 0x5, "VIBRATION INDUCED TRACKING ERROR") \
 SENSE_CODE(0xa, 0x0, "ERROR LOG OVERFLOW") \
 SENSE_CODE(0xb, 0x0, "WARNING") \
 SENSE_CODE(0xb, 0x1, "WARNING - SPECIFIED TEMPERATURE EXCEEDED") \
@@ -83,6 +90,14 @@ SENSE_CODE(0xb, 0x6, "WARNING - NON-VOLATILE CACHE NOW VOLATILE") \
 SENSE_CODE(0xb, 0x7, "WARNING - DEGRADED POWER TO NON-VOLATILE CACHE") \
 SENSE_CODE(0xb, 0x8, "WARNING - POWER LOSS EXPECTED") \
 SENSE_CODE(0xb, 0x9, "WARNING - DEVICE STATISTICS NOTIFICATION ACTIVE") \
+SENSE_CODE(0xb, 0xa, "WARNING - HIGH CRITICAL TEMPERATURE LIMIT EXCEEDED") \
+SENSE_CODE(0xb, 0xb, "WARNING - LOW CRITICAL TEMPERATURE LIMIT EXCEEDED") \
+SENSE_CODE(0xb, 0xc, "WARNING - HIGH OPERATING TEMPERATURE LIMIT EXCEEDED") \
+SENSE_CODE(0xb, 0xd, "WARNING - LOW OPERATING TEMPERATURE LIMIT EXCEEDED") \
+SENSE_CODE(0xb, 0xe, "WARNING - HIGH CRITICAL HUMIDITY LIMIT EXCEEDED") \
+SENSE_CODE(0xb, 0xf, "WARNING - LOW CRITICAL HUMIDITY LIMIT EXCEEDED") \
+SENSE_CODE(0xb, 0x10, "WARNING - HIGH OPERATING HUMIDITY LIMIT EXCEEDED") \
+SENSE_CODE(0xb, 0x11, "WARNING - LOW OPERATING HUMIDITY LIMIT EXCEEDED") \
 SENSE_CODE(0xc, 0x0, "WRITE ERROR") \
 SENSE_CODE(0xc, 0x1, "WRITE ERROR - RECOVERED WITH AUTO REALLOCATION") \
 SENSE_CODE(0xc, 0x2, "WRITE ERROR - AUTO REALLOCATION FAILED") \
@@ -99,6 +114,7 @@ SENSE_CODE(0xc, 0xc, "WRITE ERROR - UNEXPECTED UNSOLICITED DATA") \
 SENSE_CODE(0xc, 0xd, "WRITE ERROR - NOT ENOUGH UNSOLICITED DATA") \
 SENSE_CODE(0xc, 0xe, "MULTIPLE WRITE ERRORS") \
 SENSE_CODE(0xc, 0xf, "DEFECTS IN ERROR WINDOW") \
+SENSE_CODE(0xc, 0x10, "INCOMPLETE MULTIPLE ATOMIC WRITE OPERATIONS") \
 SENSE_CODE(0xd, 0x0, "ERROR DETECTED BY THIRD PARTY TEMPORARY INITIATOR") \
 SENSE_CODE(0xd, 0x1, "THIRD PARTY DEVICE FAILURE") \
 SENSE_CODE(0xd, 0x2, "COPY TARGET DEVICE NOT REACHABLE") \
@@ -204,6 +220,10 @@ SENSE_CODE(0x21, 0x0, "LOGICAL BLOCK ADDRESS OUT OF RANGE") \
 SENSE_CODE(0x21, 0x1, "INVALID ELEMENT ADDRESS") \
 SENSE_CODE(0x21, 0x2, "INVALID ADDRESS FOR WRITE") \
 SENSE_CODE(0x21, 0x3, "INVALID WRITE CROSSING LAYER JUMP") \
+SENSE_CODE(0x21, 0x4, "UNALIGNED WRITE COMMAND") \
+SENSE_CODE(0x21, 0x5, "WRITE BOUNDARY VIOLATION") \
+SENSE_CODE(0x21, 0x6, "ATTEMPT TO READ INVALID DATA") \
+SENSE_CODE(0x21, 0x7, "READ BOUNDARY VIOLATION") \
 SENSE_CODE(0x22, 0x0, "ILLEGAL FUNCTION (USE 20 00, 24 00, OR 26 00)") \
 SENSE_CODE(0x23, 0x0, "INVALID TOKEN OPERATION, CAUSE NOT REPORTABLE") \
 SENSE_CODE(0x23, 0x1, "INVALID TOKEN OPERATION, UNSUPPORTED TOKEN TYPE") \
@@ -245,6 +265,7 @@ SENSE_CODE(0x26, 0xf, "INVALID DATA-OUT BUFFER INTEGRITY CHECK VALUE") \
 SENSE_CODE(0x26, 0x10, "DATA DECRYPTION KEY FAIL LIMIT REACHED") \
 SENSE_CODE(0x26, 0x11, "INCOMPLETE KEY-ASSOCIATED DATA SET") \
 SENSE_CODE(0x26, 0x12, "VENDOR SPECIFIC KEY REFERENCE NOT FOUND") \
+SENSE_CODE(0x26, 0x13, "APPLICATION TAG MODE PAGE IS INVALID") \
 SENSE_CODE(0x27, 0x0, "WRITE PROTECTED") \
 SENSE_CODE(0x27, 0x1, "HARDWARE WRITE PROTECTED") \
 SENSE_CODE(0x27, 0x2, "LOGICAL UNIT SOFTWARE WRITE PROTECTED") \
@@ -253,6 +274,7 @@ SENSE_CODE(0x27, 0x4, "PERSISTENT WRITE PROTECT") \
 SENSE_CODE(0x27, 0x5, "PERMANENT WRITE PROTECT") \
 SENSE_CODE(0x27, 0x6, "CONDITIONAL WRITE PROTECT") \
 SENSE_CODE(0x27, 0x7, "SPACE ALLOCATION FAILED WRITE PROTECT") \
+SENSE_CODE(0x27, 0x8, "ZONE IS READ ONLY") \
 SENSE_CODE(0x28, 0x0, "NOT READY TO READY CHANGE, MEDIUM MAY HAVE CHANGED") \
 SENSE_CODE(0x28, 0x1, "IMPORT OR EXPORT ELEMENT ACCESSED") \
 SENSE_CODE(0x28, 0x2, "FORMAT-LAYER MAY HAVE CHANGED") \
@@ -299,6 +321,8 @@ SENSE_CODE(0x2c, 0x9, "PREVIOUS RESERVATION CONFLICT STATUS") \
 SENSE_CODE(0x2c, 0xa, "PARTITION OR COLLECTION CONTAINS USER OBJECTS") \
 SENSE_CODE(0x2c, 0xb, "NOT RESERVED") \
 SENSE_CODE(0x2c, 0xc, "ORWRITE GENERATION DOES NOT MATCH") \
+SENSE_CODE(0x2c, 0xd, "RESET WRITE POINTER NOT ALLOWED") \
+SENSE_CODE(0x2c, 0xe, "ZONE IS OFFLINE") \
 SENSE_CODE(0x2d, 0x0, "OVERWRITE ERROR ON UPDATE IN PLACE") \
 SENSE_CODE(0x2e, 0x0, "INSUFFICIENT TIME FOR OPERATION") \
 SENSE_CODE(0x2e, 0x1, "COMMAND TIMEOUT BEFORE PROCESSING") \
@@ -408,6 +432,7 @@ SENSE_CODE(0x3f, 0x12, "iSCSI IP ADDRESS ADDED") \
 SENSE_CODE(0x3f, 0x13, "iSCSI IP ADDRESS REMOVED") \
 SENSE_CODE(0x3f, 0x14, "iSCSI IP ADDRESS CHANGED") \
 SENSE_CODE(0x3f, 0x15, "INSPECT REFERRALS SENSE DESCRIPTORS") \
+SENSE_CODE(0x3f, 0x16, "MICROCODE HAS BEEN CHANGED WITHOUT RESET") \
 SENSE_CODE(0x40, 0x0, "RAM FAILURE (SHOULD USE 40 NN)") \
 SENSE_CODE_KEYED(0x40, "DIAGNOSTIC FAILURE ON COMPONENT %u (80h-FFh)") \
 SENSE_CODE(0x41, 0x0, "DATA PATH FAILURE (SHOULD USE 40 NN)") \
@@ -489,6 +514,7 @@ SENSE_CODE(0x55, 0xa, "DATA CURRENTLY UNAVAILABLE") \
 SENSE_CODE(0x55, 0xb, "INSUFFICIENT POWER FOR OPERATION") \
 SENSE_CODE(0x55, 0xc, "INSUFFICIENT RESOURCES TO CREATE ROD") \
 SENSE_CODE(0x55, 0xd, "INSUFFICIENT RESOURCES TO CREATE ROD TOKEN") \
+SENSE_CODE(0x55, 0xe, "INSUFFICIENT ZONE RESOURCES") \
 SENSE_CODE(0x57, 0x0, "UNABLE TO RECOVER TABLE-OF-CONTENTS") \
 SENSE_CODE(0x58, 0x0, "GENERATION DOES NOT EXIST") \
 SENSE_CODE(0x59, 0x0, "UPDATED BLOCK READ") \
