@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 
 import sys
 import yaml
@@ -48,10 +48,11 @@ def emit_header(structs):
 def emit_prefix():
 	print('#include "ata.h"')
 	print('#include "ata_parse.h"')
+	print('#include "ata_identify_dump.h"')
 	print('#include <stdio.h>')
 
 def emit_suffix():
-	print()
+	print('')
 
 def convert_def(filename):
 	f = file(filename)
